@@ -8,7 +8,9 @@ import numpy as np
 from bs4 import BeautifulSoup
 from scipy.stats import norm, mstats
 from urllib.parse import quote
+from urllib.parse import unquote
 warnings.filterwarnings("ignore")
+from requests.adapters import HTTPAdapter
 
 
 '''
@@ -40,6 +42,8 @@ warnings.filterwarnings("ignore")
 
 # 保持会话；
 session = requests.session()
+session.mount('http://', HTTPAdapter(max_retries=3))
+session.mount('https://', HTTPAdapter(max_retries=3))
 today_date = datetime.date.today()
 one_day = datetime.timedelta(days=1)
 
@@ -549,6 +553,20 @@ class Get_App_Appinfo(Qimai_Diy_Var):
         self.app_version_data = res.json()
         return self.app_version_data
 
+    def get_baseinfo_parameter(self, user_type_name='支持网站'):
+        """
+            * 获取baseinfo接口下详细参数值，自行指定获取哪个：
+            :param user_type_name: 需要获取的参数名，默认“支持网站”；
+        """
+        self.get_baseinfo()
+        for base_info in self.app_baseinfo_data['appInfo']:
+            type_name = base_info['name']
+            if type_name == user_type_name:
+                app_url = base_info['value']
+                return app_url
+        else:
+            return '未找到'
+
 # 获取榜单相关数据；
 class Get_App_Rank(Qimai_Diy_Var):
     """
@@ -633,7 +651,7 @@ class Get_App_SamePubApp(Get_App_Appinfo, Qimai_Diy_Var):
             else:
                 return '', ''
 
-    def samePubApp_sorce(self):
+    def get_samePubApp_sorce(self):
         """
             * 获取开发商权重评分(自带算法)；
         """
@@ -923,10 +941,11 @@ class Get_App_Keyword(Qimai_Diy_Var):
         self.json_df.columns = ['关键词ID', '关键词', '排名', '变动前排名', '排名变动值', '指数', '结果数', '未知1', '未知2']
         return self.json_df
 
-    def app_cover_regular(self):
+    def get_app_cover_regular(self, qualified_keyword_num=3000):
         """
             * 判断产品的覆盖数量是否合格(专用)：
             * 返回是否合格、总覆盖数、T3数、T10数；
+            :param qualified_keyword_num: 大于等于多少的算合格，默认3000；
         """
         self.get_keywordSummary()
         for keywordSummary_info in self.app_keywordSummary['keywordSummary']:
@@ -935,7 +954,7 @@ class Get_App_Keyword(Qimai_Diy_Var):
                 all_keyword = keywordSummary_info['all']['num']
                 top3_keyword = keywordSummary_info['top3']['num']
                 top10_keyword = keywordSummary_info['top10']['num']
-                if int(all_keyword) >= 3000:
+                if int(all_keyword) >= qualified_keyword_num:
                     return ['覆盖合格', all_keyword, top3_keyword, top10_keyword]
                 else:
                     return ['覆盖不合格', all_keyword, top3_keyword, top10_keyword]
@@ -1199,7 +1218,7 @@ class Get_App_Recommend(Qimai_Diy_Var):
         self.app_engagement = res.json()
         return self.app_engagement
 
-    def featured_is_match(self):
+    def get_featured_is_match(self):
         """
             * 上精品推荐匹配函数：
             * 匹配产品是否上过推荐；
@@ -1211,7 +1230,7 @@ class Get_App_Recommend(Qimai_Diy_Var):
         else:
             return ['无推荐', tuijian_num]
 
-    def featured_type_match(self, match_type='Today'):
+    def get_featured_type_match(self, match_type='Today'):
         """
             * 上精品推荐匹配函数：
             * 匹配上某个类型的次数、时长；
